@@ -46,8 +46,9 @@ from plainbox.impl.secure.qualifiers import OperatorMatcher
 from plainbox.impl.secure.qualifiers import RegExpJobQualifier
 from plainbox.impl.secure.qualifiers import select_jobs
 from plainbox.impl.session import SessionMetaData
-from plainbox.impl.transport import get_all_transports
+from plainbox.impl.session.jobs import InhibitionCause
 from plainbox.impl.transport import TransportError
+from plainbox.impl.transport import get_all_transports
 from plainbox.vendor.textland import get_display
 
 from checkbox_ng.misc import SelectableJobTreeNode
@@ -203,7 +204,11 @@ class CliInvocation2(RunInvocation):
         self.print_estimated_duration()
         self.run_all_selected_jobs()
         if self.is_interactive:
-            self.maybe_rerun_jobs()
+            while True:
+                if self.maybe_rerun_jobs():
+                    continue
+                else:
+                    break
         self.export_and_send_results()
         if SessionMetaData.FLAG_INCOMPLETE in self.metadata.flags:
             print(self.C.header("Session Complete!", "GREEN"))
@@ -314,7 +319,7 @@ class CliInvocation2(RunInvocation):
         # NOTE: tree.selection is correct but ordered badly.  To retain
         # the original ordering we should just treat it as a mask and
         # use it to filter jobs from desired_job_list.
-        wanted_set = frozenset(tree.selection)
+        wanted_set = frozenset(tree.selection + tree.resource_jobs)
         job_list = [job for job in self.manager.state.run_list
                     if job in wanted_set]
         self._update_desired_job_list(job_list)
@@ -487,29 +492,41 @@ class CliInvocation2(RunInvocation):
                 print(str(exc))
 
     def maybe_rerun_jobs(self):
-        def rerun_predicate(job_state):
-            return job_state.result.outcome in (
-                IJobResult.OUTCOME_FAIL, IJobResult.OUTCOME_CRASH)
         # create a list of jobs that qualify for rerunning
         rerun_candidates = []
         for job in self.manager.state.run_list:
-            if rerun_predicate(self.manager.state.job_state_map[job.id]):
+            job_state = self.manager.state.job_state_map[job.id]
+            if job_state.result.outcome in (
+                IJobResult.OUTCOME_FAIL, IJobResult.OUTCOME_CRASH,
+                    IJobResult.OUTCOME_NOT_SUPPORTED):
                 rerun_candidates.append(job)
+
         # bail-out early if no job qualifies for rerunning
         if not rerun_candidates:
-            return
+            return False
         tree = SelectableJobTreeNode.create_tree(
             self.manager.state, rerun_candidates)
+        # nothing to select in root node and categories - bailing out
+        if not tree.jobs and not tree._categories:
+            return False
         # deselect all by default
         tree.set_descendants_state(False)
         self.display.run(ShowRerun(tree, _("Select jobs to re-run")))
         wanted_set = frozenset(tree.selection)
         if not wanted_set:
             # nothing selected - nothing to run
-            return
-        # reset outcome of jobs that are selected for re-running
+            return False
+        # include resource jobs that selected jobs depend on
+        resources_to_rerun = []
         for job in wanted_set:
+            job_state = self.manager.state.job_state_map[job.id]
+            for inhibitor in job_state.readiness_inhibitor_list:
+                if inhibitor.cause == InhibitionCause.FAILED_DEP:
+                    resources_to_rerun.append(inhibitor.related_job)
+        # reset outcome of jobs that are selected for re-running
+        for job in list(wanted_set) + resources_to_rerun:
             from plainbox.impl.result import MemoryJobResult
             self.manager.state.job_state_map[job.id].result = \
                 MemoryJobResult({})
         self.run_all_selected_jobs()
+        return True
