@@ -94,12 +94,17 @@ class SubmitCommand(PlainBoxCommand):
         return SubmitInvocation(ns).run()
 
     def register_parser(self, subparsers):
-        parser = subparsers.add_parser("submit", help=_("submit test results to the Canonical certification website"))
+        parser = subparsers.add_parser("submit", help=_(
+            "submit test results to the Canonical certification website"))
         self.register_arguments(parser)
 
     def register_arguments(self, parser):
         parser.set_defaults(command=self)
+        parser.add_argument(
+            'submission', help=_("The path to the results xml file"))
+        self.register_optional_arguments(parser, required=True)
 
+    def register_optional_arguments(self, parser, required=False):
         if self.config.secure_id is not Unset:
             parser.set_defaults(secure_id=self.config.secure_id)
 
@@ -109,12 +114,41 @@ class SubmitCommand(PlainBoxCommand):
                     _("must be 15 or 18-character alphanumeric string"))
             return secure_id
 
+        required_check = False
+        if required:
+            required_check = self.config.secure_id is Unset
         parser.add_argument(
-            'secure_id', metavar=_("SECURE-ID"),
+            '--secure_id', metavar=_("SECURE-ID"),
+            required=required_check,
             type=secureid,
             help=_("associate submission with a machine using this SECURE-ID"))
-        parser.add_argument('submission',
-            help=_("The path to the results xml file"))
+
+        # Interpret this setting here
+        # Please remember the Unset.__bool__() return False
+        # After Interpret the setting,
+        # self.config.submit_to_c3 should has value or be Unset.
+        try:
+            if (self.config.submit_to_c3 and
+                (self.config.submit_to_c3.lower() in ('yes', 'true') or
+                    int(self.config.submit_to_c3) == 1)):
+                # self.config.c3_url has a default value written in config.py
+                parser.set_defaults(url=self.config.c3_url)
+            else:
+                # if submit_to_c3 is castable to int but not 1
+                # this is still set as Unset
+                # otherwise url requirement will be None
+                self.config.submit_to_c3 = Unset
+        except ValueError:
+            # When submit_to_c3 is something other than 'yes', 'true',
+            # castable to integer, it raises ValueError.
+            # e.g. 'no', 'false', 'asdf' ...etc.
+            # In this case, it is still set as Unset.
+            self.config.submit_to_c3 = Unset
+
+        required_check = False
+        if required:
+            required_check = self.config.submit_to_c3 is Unset
         parser.add_argument(
-            '--url', metavar=_("URL"), required=True,
+            '--url', metavar=_("URL"),
+            required=required_check,
             help=_("destination to submit to"))
